import abc
import builtins
import datetime
import enum
import typing

import jsii
import publication
import typing_extensions

import aws_cdk.aws_cloudtrail._jsii
import aws_cdk.aws_cloudwatch._jsii
import aws_cdk.aws_events._jsii
import aws_cdk.aws_iam._jsii
import aws_cdk.aws_lambda._jsii
import aws_cdk.aws_logs._jsii
import aws_cdk.aws_s3._jsii
import aws_cdk.aws_stepfunctions._jsii
import aws_cdk.aws_stepfunctions_tasks._jsii
import aws_cdk.core._jsii
import aws_solutions_constructs.aws_events_rule_step_function._jsii
import aws_solutions_constructs.core._jsii
import constructs._jsii

__jsii_assembly__ = jsii.JSIIAssembly.load(
    "@aws-solutions-constructs/aws-s3-step-function",
    "1.61.1",
    __name__[0:-6],
    "aws-s3-step-function@1.61.1.jsii.tgz",
)

__all__ = [
    "__jsii_assembly__",
]

publication.publish()
